from selenium import webdriver
import sys
import webbrowser


__version__ = '1.2'


class Googler(object):
    def __init__(self, query):
        super(Googler, self).__init__()
        self.google_link = 'https://www.google.com/search?q='
        self.query = self.google_link + '+'.join(query)

    def search_in_new_tab(self):
        webbrowser.open_new_tab(self.query)
        return self.query

    def search_in_new_private_tab(self):
        firefox_profile = webdriver.FirefoxProfile()
        firefox_profile.set_preference("browser.privatebrowsing.autostart", True)
        driver = webdriver.Firefox(firefox_profile=firefox_profile)
        driver.get(self.query)
        return  self.query




#!/usr/bin/env python3
import click
from . import Googler as g


@click.command()
@click.argument('query', nargs=-1)
@click.option('--private', '-p', is_flag=True, type=bool, help='Use to search privately')
def search_in_google(query, private: bool):
    if private:
        g(query).search_in_new_private_tab()
    else:
        g(query).search_in_new_tab()


if __name__ == '__main__':
    search_in_google()



from setuptools import setup, find_packages
from os.path import join, dirname
from pkg_resources import parse_requirements
import utils


setup(
    name='ggoogle',
    version=utils.__version__,
    packages=find_packages(),
    install_reqs = parse_requirements('requirements.txt'),
    long_description=open(join(dirname(__file__), 'README.md')).read(),
    long_description_content_type = 'text/markdown',
    entry_points={
        'console_scripts':
        ['g = utils.__main__:search_in_google']
    },
)
